@@ -193,10 +193,9 @@ sjt.corr <- function(data,
       for (i in 1:ncol(df)) {
         pv <- c()
         for (j in 1:ncol(df)) {
-          test <- cor.test(df[[i]], 
-                           df[[j]], 
-                           alternative = "two.sided", 
-                           method = corr.method)
+          test <- suppressWarnings(stats::cor.test(df[[i]], df[[j]], 
+                                                   alternative = "two.sided", 
+                                                   method = corr.method))
           pv <- cbind(pv, round(test$p.value, 5))
         }
         cp <- rbind(cp, pv)
