@@ -10,38 +10,36 @@
 #'                or saves it as file. Helpful if you want a quick overview of a data frame's 
 #'                content. See argument \code{describe} for details. By default, \code{describe} 
 #'                is \code{TRUE} and a description of the data frame is given,
-#'                using the \code{\link[psych]{describe}} function of the \code{psych} package.
+#'                using the \code{\link[psych]{describe}}-function of the \pkg{psych}-package.
 #'
 #' @param mydf data frame that should be printed as table
 #' @param describe logical, if \code{TRUE} (default), a description of the data frame's variables is given.
 #'          The description is retrieved from the \code{\link[psych]{describe}} function. 
 #'          If \code{describe = FALSE}, the data frame's content (values) is shown.
-#' @param alternateRowColors logical, if \code{TRUE}, alternating rows are highlighted with a light gray
-#'          background color.
-#' @param orderColumn indicates a column, either by column name or by column index number,
+#' @param sort.col indicates a column, either by column name or by column index number,
 #'          that should be sorted. Default order is ascending, which can be changed with
-#'          \code{orderAscending} argument. Default is \code{NULL}, hence the data frame
+#'          \code{sort.asc} argument. Default is \code{NULL}, hence the data frame
 #'          is printed with no specific order. See 'Examples'.
-#' @param orderAscending logical, if \code{TRUE} (default) and \code{orderColumn} is not \code{NULL},
+#' @param sort.asc logical, if \code{TRUE} (default) and \code{sort.col} is not \code{NULL},
 #'          data frame is ordered according to the specified column in an ascending order.
 #'          Use \code{FALSE} to apply descending order. See 'Examples'.
 #' @param title table caption. By default, \code{title = NULL}, hence no title will be used.
-#' @param stringVariable string, label used for the first column name. Default is \code{"Variable"}.
-#' @param repeatHeader logical, if \code{TRUE}, the header row will also be added at the bottom at the table. This might
+#' @param string.var string, label used for the first column name. Default is \code{"Variable"}.
+#' @param repeat.header logical, if \code{TRUE}, the header row will also be added at the bottom at the table. This might
 #'          be helpful, if you have longer tables and want to see the column names at the end of the table as well.
-#' @param showType logical, if \code{TRUE}, the variable type is shown in a separate row below the column
-#'          names.
-#' @param showRowNames logical, if \code{TRUE} and \code{describe = FALSE}, 
+#' @param show.type logical, if \code{TRUE}, the variable type is shown in a separate
+#'          row respectively column.
+#' @param show.rownames logical, if \code{TRUE} and \code{describe = FALSE}, 
 #'          first table column contains row names of data frame. Use 
-#'          \code{showRowNames = FALSE} to omit first table column with row names.
-#' @param showCommentRow logical, if \code{TRUE}, an optional comment line can be added to the end / below
-#'          the table. Use \code{commentString} to specify the comment.
-#' @param commentString string that will be added to the end / below the table. Only
-#'          applies, if \code{showCommentRow = TRUE}.
+#'          \code{show.rownames = FALSE} to omit first table column with row names.
+#' @param show.cmmn.row logical, if \code{TRUE}, an optional comment line can be added to the end / below
+#'          the table. Use \code{string.cmmn} to specify the comment.
+#' @param string.cmmn string that will be added to the end / below the table. Only
+#'          applies, if \code{show.cmmn.row = TRUE}.
 #' @param big.mark character; if not \code{NULL}, used as mark between every 
 #'          thousands decimals before (hence big) the decimal point
-#' @param hideProgressBar logical, if \code{TRUE}, the progress bar that is displayed when creating the
-#'          table is hidden. Default in \code{FALSE}, hence the bar is visible.
+#' @param hide.progress logical, if \code{TRUE}, the progress bar that is displayed when creating the
+#'          output is hidden. Default in \code{FALSE}, hence the bar is visible.
 #' @param ... other arguments passed down to the \code{\link[psych]{describe}} function.
 #'          
 #' @inheritParams sjt.frq
@@ -67,41 +65,29 @@
 #' data(efc)
 #' 
 #' # plot efc-data frame summary
-#' sjt.df(efc, alternateRowColors = TRUE)
+#' sjt.df(efc, altr.row.col = TRUE)
 #' 
 #' # plot content, first 50 rows of first 5 columns of example data set
-#' sjt.df(efc[1:50, 1:5], 
-#'        describe = FALSE, 
-#'        stringVariable = "Observation")
+#' sjt.df(efc[1:50, 1:5], describe = FALSE, string.var = "Observation")
 #' 
 #' # plot efc-data frame summary, sorted descending by mean-column
-#' sjt.df(efc, 
-#'        orderColumn = "mean", 
-#'        orderAscending = FALSE)
+#' sjt.df(efc, sort.col = "mean", sort.asc = FALSE)
 #' 
 #' # plot first 20 rows of first 5 columns of example data set,
 #' # sort by column "e42dep" with alternating row colors
-#' sjt.df(efc[1:20, 1:5], 
-#'        alternateRowColors = TRUE, 
-#'        orderColumn = "e42dep", 
-#'        describe = FALSE)
+#' sjt.df(efc[1:20, 1:5], altr.row.col = TRUE, 
+#'        sort.col = "e42dep", describe = FALSE)
 #' 
 #' # plot first 20 rows of first 5 columns of example data set,
 #' # sorted by 4th column in descending order.
-#' sjt.df(efc[1:20, 1:5], 
-#'        orderColumn = 4, 
-#'        orderAscending = FALSE, 
-#'        describe = FALSE)
+#' sjt.df(efc[1:20, 1:5], sort.col = 4, sort.asc = FALSE, describe = FALSE)
 #' 
 #' # add big mark to thousands
 #' library(datasets)
 #' sjt.df(as.data.frame(WorldPhones), big.mark = ",")
 #' 
-#' # ---------------------------------------------------------------- 
 #' # User defined style sheet
-#' # ---------------------------------------------------------------- 
-#' sjt.df(efc,
-#'        alternateRowColor = TRUE,
+#' sjt.df(efc, altr.row.col = TRUE, 
 #'        CSS = list(css.table = "border: 2px solid #999999;",
 #'                   css.tdata = "border-top: 1px solid;",
 #'                   css.arc = "color:blue;"))}
@@ -111,22 +97,22 @@
 #' @export
 sjt.df <- function(mydf,
                    describe = TRUE,
-                   file = NULL,
-                   alternateRowColors = FALSE,
-                   orderColumn = NULL,
-                   orderAscending = TRUE,
+                   altr.row.col = FALSE,
+                   sort.col = NULL,
+                   sort.asc = TRUE,
                    title = NULL,
-                   repeatHeader = FALSE,
-                   stringVariable = "Variable",
-                   showType = FALSE,
-                   showRowNames = TRUE,
-                   showCommentRow = FALSE,
-                   commentString = "No comment...",
+                   repeat.header = FALSE,
+                   show.type = FALSE,
+                   show.rownames = TRUE,
+                   show.cmmn.row = FALSE,
+                   string.cmmn = "No comment...",
+                   string.var = "Variable",
                    big.mark = NULL,
-                   hideProgressBar = FALSE,
-                   encoding = NULL,
+                   hide.progress = FALSE,
                    CSS = NULL,
-                   useViewer = TRUE,
+                   encoding = NULL,
+                   file = NULL, 
+                   use.viewer = TRUE,
                    no.output = FALSE,
                    remove.spaces = TRUE,
                    ...) {
@@ -137,7 +123,7 @@ sjt.df <- function(mydf,
   # unique handling for the data
   # -------------------------------------
   if (!is.data.frame(mydf)) {
-    stop("argument needs to be a data frame!", call. = FALSE)
+    stop("`mydf` needs to be a data frame!", call. = FALSE)
   }
   # -------------------------------------
   # Description?
@@ -149,10 +135,7 @@ sjt.df <- function(mydf,
     missings.percentage <- round(100 * missings / nrow(mydf), 2)
     mydf <- round(psych::describe(mydf, ...), 2)
     # insert missing variables in data frame
-    mydf <- data.frame(mydf[, 1:2], 
-                       missings, 
-                       missings.percentage, 
-                       mydf[, 3:ncol(mydf)])
+    mydf <- data.frame(mydf[, 1:2], missings, missings.percentage, mydf[, 3:ncol(mydf)])
     # proper column name
     colnames(mydf)[4] <- "missings (percentage)"
     # want to insert a thousands big mark?
@@ -168,19 +151,19 @@ sjt.df <- function(mydf,
   # -------------------------------------
   # Order data set if requested
   # -------------------------------------
-  if (!is.null(orderColumn)) {
-    # check whether orderColumn is numeric or character
-    if (is.character(orderColumn)) {
-      # retrieve column that equals orderColumn string
-      nr <- which(colnames(mydf) == orderColumn)
-      orderColumn <- as.numeric(nr)
+  if (!is.null(sort.col)) {
+    # check whether sort.col is numeric or character
+    if (is.character(sort.col)) {
+      # retrieve column that equals sort.col string
+      nr <- which(colnames(mydf) == sort.col)
+      sort.col <- as.numeric(nr)
     }
     # check for correct range
-    if (is.numeric(orderColumn) && orderColumn > 0 && orderColumn <= ncol(mydf)) {
+    if (is.numeric(sort.col) && sort.col > 0 && sort.col <= ncol(mydf)) {
       # retrieve order
-      rfolge <- order(mydf[[orderColumn]])
+      rfolge <- order(mydf[[sort.col]])
       # reverse order?
-      if (!orderAscending) rfolge <- rev(rfolge)
+      if (!sort.asc) rfolge <- rev(rfolge)
       # sort dataframe
       mydf <- mydf[rfolge, ]
     }
@@ -212,7 +195,7 @@ sjt.df <- function(mydf,
   css.leftalign <- "text-align:left;"
   css.centertalign <- "text-align:center;"
   css.comment <- "font-style:italic; border-top:double black; text-align:right;"
-  if (showCommentRow && repeatHeader) css.comment <- "font-style:italic; text-align:right;"
+  if (show.cmmn.row && repeat.header) css.comment <- "font-style:italic; text-align:right;"
   # ------------------------
   # check user defined style sheets
   # ------------------------
@@ -262,22 +245,20 @@ sjt.df <- function(mydf,
   # -------------------------------------
   page.content <- paste0(page.content, "  <tr>\n")
   # first columns are rownames
-  if (showRowNames) page.content <- paste0(page.content, sprintf("    <th class=\"thead firsttablerow firsttablecol\">%s</th>\n", stringVariable))
+  if (show.rownames) page.content <- paste0(page.content, sprintf("    <th class=\"thead firsttablerow firsttablecol\">%s</th>\n", string.var))
   for (i in 1:colcnt) {
     # check variable type
     vartype <- get.vartype(mydf[[i]])
     # column names and variable as table headline
     page.content <- paste0(page.content, sprintf("    <th class=\"thead firsttablerow\">%s", cnames[i]))
-    if (showType) page.content <- paste0(page.content, sprintf("<br>(%s)", vartype))
+    if (show.type) page.content <- paste0(page.content, sprintf("<br>(%s)", vartype))
     page.content <- paste0(page.content, "</th>\n")
   }
   page.content <- paste0(page.content, "  </tr>\n")
   # -------------------------------------
   # create progress bar
   # -------------------------------------
-  if (!hideProgressBar) pb <- utils::txtProgressBar(min = 0, 
-                                                    max = rowcnt, 
-                                                    style = 3)
+  if (!hide.progress) pb <- utils::txtProgressBar(min = 0, max = rowcnt, style = 3)
   # -------------------------------------
   # subsequent rows
   # -------------------------------------
@@ -285,32 +266,32 @@ sjt.df <- function(mydf,
     # default row string
     arcstring <- ""
     # if we have alternating row colors, set css
-    if (alternateRowColors) arcstring <- ifelse(sjmisc::is_even(rcnt), " arc", "")
+    if (altr.row.col) arcstring <- ifelse(sjmisc::is_even(rcnt), " arc", "")
     page.content <- paste0(page.content, "  <tr>\n")
     # first table cell is rowname
-    if (showRowNames) page.content <- paste0(page.content, sprintf("    <td class=\"tdata leftalign firsttablecol%s\">%s</td>\n", arcstring, rnames[rcnt]))
+    if (show.rownames) page.content <- paste0(page.content, sprintf("    <td class=\"tdata leftalign firsttablecol%s\">%s</td>\n", arcstring, rnames[rcnt]))
     # all columns of a row
     for (ccnt in 1:colcnt) {
       page.content <- paste0(page.content, sprintf("    <td class=\"tdata centertalign%s\">%s</td>\n", arcstring, mydf[rcnt, ccnt]))
     }
     # update progress bar
-    if (!hideProgressBar) utils::setTxtProgressBar(pb, rcnt)
+    if (!hide.progress) utils::setTxtProgressBar(pb, rcnt)
     # close row tag
     page.content <- paste0(page.content, "</tr>\n")
   }
-  if (!hideProgressBar) close(pb)
+  if (!hide.progress) close(pb)
   # -------------------------------------
   # repeat header row?
   # -------------------------------------
-  if (repeatHeader) {
+  if (repeat.header) {
     page.content <- paste0(page.content, "  <tr>\n")
-    if (showRowNames) page.content <- paste0(page.content, sprintf("    <th class=\"thead lasttablerow firsttablecol\">%s</th>\n", stringVariable))
+    if (show.rownames) page.content <- paste0(page.content, sprintf("    <th class=\"thead lasttablerow firsttablecol\">%s</th>\n", string.var))
     for (i in 1:colcnt) {
       # check variable type
       vartype <- get.vartype(mydf[[i]])
       # column names and variable as table headline
       page.content <- paste0(page.content, sprintf("    <th class=\"thead lasttablerow\">%s", cnames[i]))
-      if (showType) page.content <- paste0(page.content, sprintf("<br>(%s)", vartype))
+      if (show.type) page.content <- paste0(page.content, sprintf("<br>(%s)", vartype))
       page.content <- paste0(page.content, "</th>\n")
     }
     page.content <- paste0(page.content, "  </tr>\n")
@@ -318,10 +299,10 @@ sjt.df <- function(mydf,
   # -------------------------------------
   # add optional "comment" row
   # -------------------------------------
-  if (showCommentRow) {
+  if (show.cmmn.row) {
     page.content <- paste0(page.content, "  <tr>\n")
-    if (!showRowNames) colcnt <- colcnt - 1
-    page.content <- paste0(page.content, sprintf("    <td colspan=\"%i\" class=\"comment\">%s</td>\n", colcnt + 1, commentString))
+    if (!show.rownames) colcnt <- colcnt - 1
+    page.content <- paste0(page.content, sprintf("    <td colspan=\"%i\" class=\"comment\">%s</td>\n", colcnt + 1, string.cmmn))
     # close row tag
     page.content <- paste0(page.content, "</tr>\n")
   }
@@ -366,7 +347,7 @@ sjt.df <- function(mydf,
   # -------------------------------------
   # check if html-content should be outputted
   # -------------------------------------
-  out.html.table(no.output, file, knitr, toWrite, useViewer)
+  out.html.table(no.output, file, knitr, toWrite, use.viewer)
   # -------------------------------------
   # return results
   # -------------------------------------
